CatCall <-
function (startX, endX, lum=4, export=F, sizePts=2, binPts=5, Span = 0, Increment=0, k=6, modulo=1440,Rverbose=0, RmaxGap=400, tz="GMT",Skip=0,nFiles=2, Smoothing=F, Actogram=F,AutoCorr=F,CrossCorr=F,Multitaper=F,Console=F,Darkness1=1,Darkness2=0,LagPcnt=.33) {
  # Span will need to be large enough not to trigger the error messages in the functions, which require more than 3 days for each analysis
  # skip, in case the header has multiple rows,some can be skipped
  # LagPcnt should be designated as a fraction, to get the highest precision, otherwise data are lost:  1/3
  #          also, the periodogram turns out with highest precision if a multiple of a full period is used.
  # lum indicates which row the lumninance is in.  Luminance values are used by the functions (except Cosinor). 
  #                    Analysis begins at lights out of the first day.
  # all functions begin their analysis at lights on point of the day, except for cosinor which starts at midnight
  # in a progression, Crosscorrelation compares the entire baseline set against each progression
#   initial.dir<-getwd()
#   # change to the new directory
#   setwd('~/Documents/Cathy/Neuroscience papers/capstone/Bartolomucci/chrono data/R-functions')
#   #funprog
#   source('~/Documents/Cathy/Neuroscience papers/capstone/Bartolomucci/chrono data/R-functions/CatBin/CatBin.R')
#   source('Smooth/Smooth.r')
#   source('AutoCorr/AutoCorr.r')
#   #source('AutoCorrRand.r')
#   source('Actogram/Actogram.r')
#   source('CrossCorr/CrossCorr.R')
#   #source('CrossCorrX.r')
#   source('MultiTaper/MultiTaper.v4.r')     #  2 periodograms, higher for use in paper
#   source('MultiTaper/MultiTaper.v2.r')     #  1 periodograms, 1 Ftest  (adjust text x length)
#   #source('~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/periCosinor.R')
#   source('Wavelet/Wavelet.r') 
#   source('Import/Import5.R')
#   #source('~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/CosinorEQ.r')
  
  View("Enter a baseline data file (tab delimited):")
  fileName <- file.choose()
  
  myHeader <- read.table(fileName, header=TRUE, nrows=1, sep="\t",skip=Skip)
  #get the header for names  -- all strings matching header will be removed
  #if (RepeatedHeaders==1){
    headerChar1 <- substr(names(myHeader)[1],1,1)    # gets the 1st character of the header to be used as a comment indicator
  #}
  #else headerChar1 <- ""               #  use NA as a comment indicator
  myData1A <- read.table(fileName, header=TRUE, sep="\t",skip=Skip,stringsAsFactors=FALSE,comment.char=headerChar1,col.names = names(myHeader))
  if (.Platform$file.sep=="/"){
    m=regexec("[^/]*$",fileName)            #  ./(.$)    pc=[^\\]*$   mac=[^/]*$
  } else {
    m=regexec("[^\\]*$",fileName)
  }
  fileName1<-regmatches(fileName,m)
  print(fileName1)          #   (for use in graph)

  myData1 = na.omit(head(myData1A,n=-2))   # drop the very last row in case it had no data
  
  myData1[,1] <- as.POSIXct(strptime(x=paste(myData1[,1],myData1[,2]), format="%d/%m/%y %H:%M:%S", tz=tz))
  myData1[,2] <- NULL
  names(myData1)[1] <- "Datetime"
  str(myData1)
  
  print("passing to import")
  myList <- do.call(Import5, list(x=myData1, tsCol=1, valCols=c(lum-2,lum-1), sumCols=c((startX-1):(endX-1)), seconds=sizePts*60, maxGap=RmaxGap, verbose=Rverbose,tz=tz))
  
  print(paste("Max gap baseline = ", myList$maxGap))
  print(paste("Percent data missing = ", myList$percentMissing))
  
  baseData<-myList$df
  if (nFiles==2){
      print("Enter an experimental data file (tab delimited):")
      file2Name <- file.choose()
      
      myHeader <- read.table(file2Name, header=TRUE, nrows=1, sep="\t",skip=Skip)
    
      #get the header for names  -- all strings matching header will be removed
        headerChar1 <- substr(names(myHeader)[1],1,1)    # gets the 1st character of the header to be used as a comment indicator
    
      myDataA <- read.table(file2Name, header=TRUE, sep="\t",skip=Skip,stringsAsFactors=FALSE,comment.char=headerChar1,col.names = names(myHeader))
      myData = na.omit(head(myDataA,n=-2))     #  get rid of all rows with NA   --head(myDataA,n=-2)
    
      #m=regexec("[^/]*$",fileName)            #  ./(.$)   [^\\/]*\s   mac=[^/]*$    [^\\]*$ 
      if (.Platform$file.sep=="/"){
        m=regexec("[^/]*$",file2Name)            #  ./(.$)    pc=[^\\]*$   mac=[^/]*$
      } else {
        m=regexec("[^\\]*$",file2Name)
      }
      file2Name1<-regmatches(file2Name,m)
      print(file2Name1)    # get rid of : from timestamp (for use in graph)
      
      #print(fileName)
      #m=regexec("^(\\\\psf.+\\)[^\\]+$",fileName)     #  ^(\\\\psf.+\\)[^\\]+$     ^(?:[^\\]*\\))*
      #print(regmatches(fileName,m))
      #filePath<-regmatches(fileName,m)[[1]][2]
      #print(filePath)
      
      myData[,1] <- as.POSIXct(strptime(x=paste(myData[,1],myData[,2]), format="%d/%m/%y %H:%M:%S", tz=tz))
      myData[,2] <- NULL
      names(myData)[1] <- "Datetime"
      myList <- do.call(Import5, list(x=myData, tsCol=1, valCols=c(lum-2,lum-1), sumCols=c((startX-1):(endX-1)), seconds=sizePts*60, maxGap=RmaxGap, verbose=Rverbose,tz=tz))
      
      print(paste("Max gap experiment = ", myList$maxGap))
      print(paste("Percent data missing = ", myList$percentMissing))
      
      #if (is.data.frame(myList$df)){
      #  View(myList$df)
      #}
      xData<-myList$df
  } 
  thisTime <- format(Sys.time(), "--%d%b,%Y--%H-%M-%S")
  fileName3 <-paste(fileName,thisTime,"output.rtf",sep="")
  fileName4 <-paste(fileName,thisTime,"output.pdf",sep="")
  #docName <- sub("-","",sub("-","",fileName,fixed=TRUE),fixed=TRUE)
  if (!Console){
    pdf(file=fileName4)                #,width=8, height=10)
  } 

  print("output fileName4")
  print(fileName4)

  if (FALSE) {  
  print("cosinor path") 
  #CosinorEQ(startX, endX, Avg=0, lum, sizePts, binPts, period=24, myData = baseData,fileName1)
  #Cosinor(TimeCol=2,Y=c(startX,endX), Units='Week', RegressionLen=1, RefDate="201302030000", SpanUnits='Day', Span=Span, Increment=Increment, header=F,oneCycle=0, Debug=FALSE,call=TRUE,data=MyData1,file=fileName1)
  #Cosinor(TimeCol=2,Y=c(startX,endX), Units='Week', RegressionLen=1, RefDate="201302030000", SpanUnits='Day', Span=Span, Increment=Increment, header=F,oneCycle=0, Debug=FALSE,call=TRUE,data=MyData,file=file2Name1)  
  } else{
  endX<-endX-1       # Import removed a column, to subtract 1
  startX<-startX-1
  lum<-lum-1
  
  baseData_len<-length(baseData[,1])         # #####################################
  nextLight<-0
  LumV <- baseData[,lum]         #   get just the luminance vector
  if (LumV[1]==0 && Darkness1==0){             #  if the first row is darkness, more into light first
    nextLight<-which(LumV>10)
    LumV<-baseData[nextLight[1]:baseData_len,lum]
  }
  if (Darkness1!=0){
    Dark <- LumV[LumV>10]       #   get values for darkness
  } else {Dark <- LumV[LumV<10]}
  startDataV <- which(LumV==Dark[1])   + nextLight[1]    #  get index of first darkness value
  startData <-startDataV[1]
  cat("darkness1",startData,"\n")
  
  
  if (nFiles==2){
    xData_len<-length(xData[,1])         # #############################################
    nextLight<-0
    LumV <- xData[,lum]         #   get just the luminance vector
    if (LumV[1]==0 && Darkness1==0){             #  if the first row is darkness, more into light first
      nextLight<-which(LumV>10)
      LumV<-xData[nextLight[1]:xData_len,lum]
    }
    if (Darkness2!=0){
      Dark <- LumV[LumV>10]       #   get values for darkness
    } else {Dark <- LumV[LumV<10]}
    startDataV <- which(LumV==Dark[1])  + nextLight[1]       #  get index of first darkness value
    startDataX <-startDataV[1]
    cat("darkness2",startDataX,"\n")
  }
  
  if (export==T){
    CatBins1<-CatBin(startX, endX, Avg=0, lum, sizePts, binPts,modulo, startData,baseData)
    # returns newMinPerBin,dataPts,binsPerDay,animals, startData, endData, DataList,plotCnt
    write.matrix(cbind(CatBins1$TimeBins,t(CatBins1$DataList)), file = paste(fileName,thisTime,"file1.txt",sep=""), sep = ",")
    if (nFiles==2){
      CatBins2<-CatBin(startX, endX, Avg=0, lum, sizePts, binPts,modulo, startDataX,xData)
      # returns newMinPerBin,dataPts,binsPerDay,animals, startData, endData, DataList,plotCnt
      write.matrix(cbind(CatBins2$TimeBins,t(CatBins2$DataList)), file = paste(file2Name,thisTime,"file2.txt",sep=""), sep = ",")
    }
  }
  
  
  if (Smoothing){
    print("smoothing")
    Smooth(startX, endX, Avg=1, lum, sizePts, binPts,k,myData = baseData[startData:baseData_len,],fileName1)  
    Smooth(startX, endX, Avg=0, lum, sizePts, binPts,k,myData = baseData[startData:baseData_len,],fileName1)

     if (nFiles==2){
        Smooth(startX, endX, Avg=1, lum, sizePts, binPts,k,myData = xData[startDataX:xData_len,],file2Name1)
        Smooth(startX, endX, Avg=0, lum, sizePts, binPts,k,myData = xData[startDataX:xData_len,],file2Name1)
     }   # end of nFiles==2
  }      # end of Smoothing
    if (Actogram){
    print("actogram")
    Actogram(startX, endX, Avg=1, lum, sizePts, binPts, modulo,myData = baseData,fileName1,startData) 
    Actogram(startX, endX, Avg=0, lum, sizePts, binPts, modulo,myData = baseData,fileName1,startData)
     if (nFiles==2){
        Actogram(startX, endX, Avg=1, lum, sizePts, binPts, modulo,myData = xData,file2Name1,startDataX)
        Actogram(startX, endX, Avg=0, lum, sizePts, binPts, modulo,myData = xData,file2Name1,startDataX)
     }   # end of nFiles==2
   }     # end of Actogram
  Others<-TRUE
  if (Others){
    #baseData_len<-length(baseData[,1])         # #####################################
    #LumV <- baseData[,lum]         #   get just the luminance vector
    #if (Darkness1!=0){
    #  Dark <- LumV[LumV>10]       #   get values for darkness
    #} else {Dark <- LumV[LumV<10]}
    #startDataV <- which(LumV==Dark[1])       #  get index of first darkness value
    #startData <-startDataV[1]
    #cat("darkness1",startData,"\n")
    #browser()
    if (Span<=0 || Increment<=0 || Increment*(1440/sizePts)>=baseData_len){
      baseIncrement<-0
      baseSpan<-baseData_len
      StartSpans<-seq(from=startData, to=baseData_len, by=baseData_len)
    }
    else {
      # Span or increment units are assumed to be in Days  X  
      baseSpan<-Span*(1440/sizePts)      # #days  X  data points per day  (minutes in a day/ length between pts)  
      baseIncrement<-Increment*(1440/sizePts)      # #days  X  new bins per day
      StartSpans<-seq(from=startData, to=(baseData_len-(baseIncrement-1)), by=baseIncrement)    #to=(baseData_len-(baseIncrement-1))
    }
    cat("Span",baseSpan,"Increment",baseIncrement,"StartSpans",StartSpans,"baseData_len",baseData_len,"\n")
    baseProgression_end<-length(StartSpans)
    
    #  move baseline autocorrelation and baseline multitaper to here    #######################################
    #browser()
    if (nFiles==2){
      #xData_len<-length(xData[,1])         # #############################################
      #LumV <- xData[,lum]         #   get just the luminance vector
      #if (Darkness2!=0){
      #  Dark <- LumV[LumV>10]       #   get values for darkness
      #} else {Dark <- LumV[LumV<10]}
      #startDataV <- which(LumV==Dark[1])       #  get index of first darkness value
      #startDataX <-startDataV[1]
      #cat("darkness2",startDataX,"\n")
      
      if (Span<=0 || Increment<=0 || Increment*(1440/sizePts)>=xData_len){
        xIncrement<-0
        xSpan<-xData_len
        xStartSpans<-seq(from=startDataX, to=xData_len, by=xData_len)
      } else {
        # Span or increment units are assumed to be in Days  X  
        xSpan<-Span*(1440/sizePts)      # #days  X  data points per day  (minutes in a day/ length between pts)  
        xIncrement<-Increment*(1440/sizePts)      # #days  X  new bins per day
        xStartSpans<-seq(from=startDataX, to=xData_len-(xIncrement-1), by=xIncrement)     # to=xData_len-(xIncrement-1)
      }
      cat("xSpan",xSpan,"xIncrement",xIncrement,"xStartSpans",xStartSpans,"xData_len",xData_len)
      xProgression_end<-length(xStartSpans)
   } else {xProgression_end<-0}
  
    if (xProgression_end>=baseProgression_end){
      Progression_end<-xProgression_end
    } else {
      Progression_end<-baseProgression_end
    }  
  baseSkip<-FALSE
  xSkip<-FALSE

    for (j in 1:Progression_end){   #  make a vector with incremental values.  use var(i) for necessary indexes
      #browser()
      #if (j<=baseProgression_end){     not needed unless progressive analysis includes file1
      #  baseSkip<-FALSE
      #  EndSpan<-StartSpans[j]+baseSpan -1      #   Add span length to the last span to get the ending of the span
      #  if (EndSpan>baseData_len){    # *****what to do about this???*********
      #    EndSpan<-baseData_len
      #  } 
      #} else {                                # if this increment is past end of Progression, skip
      #    baseSkip <-TRUE
      #  }
      if (xProgression_end>=j){
        xSkip<-FALSE
        xEndSpan<-xStartSpans[j]+xSpan -1      #   Add span length to the last span to get the ending of the span
        if (xEndSpan>xData_len){      # *****what to do about this???**********
          xEndSpan<-xData_len
        }
      } else {                                 # if this increment is past end of Progression, skip
          xSkip <-TRUE
      }
      if (1==1) {  
        if (AutoCorr){
          print("AutoCorr")
          if (!baseSkip){
            AutoCorr(startX, endX, Avg=1, lum, sizePts, binPts, myData = baseData[startData:baseData_len,],fileName1,Span = Span, Increment=Increment,LagPcnt=LagPcnt )
            AutoCorr(startX, endX, Avg=0, lum, sizePts, binPts,myData = baseData[startData:baseData_len,],fileName1,Span = Span, Increment=Increment,LagPcnt=LagPcnt )
          }
          if (!xSkip & nFiles==2){
            AutoCorr(startX, endX, Avg=1, lum, sizePts, binPts,myData = xData[xStartSpans[j]:xEndSpan,],file2Name1,Span = Span, Increment=Increment,LagPcnt=LagPcnt)
            AutoCorr(startX, endX, Avg=0, lum, sizePts, binPts,myData = xData[xStartSpans[j]:xEndSpan,],file2Name1,Span = Span, Increment=Increment,LagPcnt=LagPcnt)
          }  
        }  #end AutoCorr
        if (CrossCorr){
          print("CrossCorr")          
          if (nFiles!=2){stop("To run CrossCorr, be sure nFiles=2;  otherwise, set CrossCorr=F")}
          if (!xSkip & nFiles==2){
            #  have to pass in start of baseline relative to dark (or phase is off!)  -- test with progressive?
            CrossCorr(startX, endX, Avg=1, lum, sizePts, binPts,myData = baseData[startData:baseData_len,],myData2 = xData[xStartSpans[j]:xEndSpan,],file2Name1,Span = Span, Increment=Increment)
            CrossCorr(startX, endX, Avg=0, lum, sizePts, binPts,myData = baseData[startData:baseData_len,],myData2 = xData[xStartSpans[j]:xEndSpan,],file2Name1,Span = Span, Increment=Increment)
          }
        }   # end CrossCorr
     }    #  end turning stuff off
      if (Multitaper==T){
        print("MultiTaper")
          #View(baseData[StartSpans[j]:EndSpan,1])
        print(format(baseData[StartSpans[j],1], "%b %d, %Y - %H:%M:%S"))
        #print(format(baseData[EndSpan,1], "%b %d, %Y - %H:%M:%S"))
        if (!xSkip){
          print(format(xData[xStartSpans[j],1], "%b %d, %Y - %H:%M:%S"))
          print(format(xData[xEndSpan,1], "%b %d, %Y - %H:%M:%S"))
       }
        if (!baseSkip){
          MultiTaper.v4(startX, endX, Avg=1, lum, sizePts, binPts,myData = baseData[startData:baseData_len,],fileName1,Span = Span, Increment=Increment )
          MultiTaper.v4(startX, endX, Avg=0, lum, sizePts, binPts,myData = baseData[startData:baseData_len,],fileName1,Span = Span, Increment=Increment)
        }
        if (!xSkip & nFiles==2){
          MultiTaper.v4(startX, endX, Avg=1, lum, sizePts, binPts,myData = xData[xStartSpans[j]:xEndSpan,],file2Name1,Span = Span, Increment=Increment)
          MultiTaper.v4(startX, endX, Avg=0, lum, sizePts, binPts,myData = xData[xStartSpans[j]:xEndSpan,],file2Name1,Span = Span, Increment=Increment)
        }
      }
      }   #   end progressive
 }   # end if OTHERS
  #MultiTaper.fpeaks(startX, endX, Avg=0, lum, sizePts, binPts,myData = baseData,fileName1)
  
      #print("Wavelet")
      #Wavelet (startX, endX, Avg=1, lum, sizePts, binPts,myData = baseData,fileName1)
      #Wavelet (startX, endX, Avg=0, lum, sizePts, binPts,myData = baseData,fileName1)
      
      #Wavelet (startX, endX, Avg=1, lum, sizePts, binPts,myData = xData,file2Name1)
      #Wavelet (startX, endX, Avg=0, lum, sizePts, binPts,myData = xData,file2Name1)
  # change back to the original directory
}
  ###setwd(initial.dir)
  
  if (!Console){  
    dev.off()
    print(paste("Output has been saved to:",fileName4))
  } 
  # close the output file
  ##sink()
  # unload the libraries
  ##detach("package:nlme")


}
